@@ -8,84 +8,39 @@ from starlette.middleware.gzip import GZipMiddleware
 from starlette.middleware.httpsredirect import HTTPSRedirectMiddleware
 from starlette.staticfiles import StaticFiles
 from starlette.templating import Jinja2Templates
-from starlette.config import Config
-from itsdangerous import Signer
 from justpy.htmlcomponents import *
 from .chartcomponents import *
 from .gridcomponents import *
 from .quasarcomponents import *
 from jpcore.template import Context
-
+from jpcore.justpy_app import cookie_signer, JustpyApp,JustpyEndpoint
+from jpcore.justpy_config import config, AGGRID, AGGRID_ENTERPRISE,BOKEH,COOKIE_MAX_AGE, CRASH
+from jpcore.justpy_config import DEBUG,DECKGL, FAVICON, HIGHCHARTS,HOST,KATEX, LATENCY,LOGGING_LEVEL
+from jpcore.justpy_config import MEMORY_DEBUG, NO_INTERNET, PLOTLY, PORT, SECRET_KEY, SESSION_COOKIE_NAME, SESSIONS
+from jpcore.justpy_config import SSL_CERTFILE, SSL_KEYFILE, SSL_VERSION, STATIC_DIRECTORY,STATIC_NAME, STATIC_ROUTE
+from jpcore.justpy_config import QUASAR, QUASAR_VERSION,TAILWIND, UVICORN_LOGGING_LEVEL, VEGA
+JustPy.LOGGING_LEVEL = LOGGING_LEVEL
 # from .misccomponents import *
 from .meadows import *
 from .pandas import *
 from .routing import Route, JpRoute, SetRoute
 from .utilities import run_task, create_delayed_task
 import uvicorn, logging, uuid, sys, os, traceback, fnmatch
-from ssl import PROTOCOL_SSLv23
 
 current_module = sys.modules[__name__]
 current_dir = os.path.dirname(current_module.__file__)
 print(current_dir.replace("\\", "/"))
 print(f"Module directory: {current_dir}, Application directory: {os.getcwd()}")
 
+TEMPLATES_DIRECTORY = config(
+    "TEMPLATES_DIRECTORY", cast=str, default=current_dir + "/templates"
+)
 #
 # globals
 #
 # uvicorn Server
 jp_server = None
 
-config = Config("justpy.env")
-DEBUG = config("DEBUG", cast=bool, default=True)
-CRASH = config("CRASH", cast=bool, default=False)
-MEMORY_DEBUG = config("MEMORY_DEBUG", cast=bool, default=False)
-if MEMORY_DEBUG:
-    import psutil
-LATENCY = config("LATENCY", cast=int, default=0)
-if LATENCY:
-    print(f"Simulating latency of {LATENCY} ms")
-SESSIONS = config("SESSIONS", cast=bool, default=True)
-SESSION_COOKIE_NAME = config("SESSION_COOKIE_NAME", cast=str, default="jp_token")
-SECRET_KEY = config(
-    "SECRET_KEY", default="$$$my_secret_string$$$"
-)  # Make sure to change when deployed
-LOGGING_LEVEL = config("LOGGING_LEVEL", default=logging.WARNING)
-JustPy.LOGGING_LEVEL = LOGGING_LEVEL
-UVICORN_LOGGING_LEVEL = config("UVICORN_LOGGING_LEVEL", default="WARNING").lower()
-COOKIE_MAX_AGE = config(
-    "COOKIE_MAX_AGE", cast=int, default=60 * 60 * 24 * 7
-)  # One week in seconds
-HOST = config("HOST", cast=str, default="127.0.0.1")
-PORT = config("PORT", cast=int, default=8000)
-SSL_VERSION = config("SSL_VERSION", default=PROTOCOL_SSLv23)
-SSL_KEYFILE = config("SSL_KEYFILE", default="")
-SSL_CERTFILE = config("SSL_CERTFILE", default="")
-
-TEMPLATES_DIRECTORY = config(
-    "TEMPLATES_DIRECTORY", cast=str, default=current_dir + "/templates"
-)
-STATIC_DIRECTORY = config("STATIC_DIRECTORY", cast=str, default=os.getcwd())
-STATIC_ROUTE = config("STATIC_MOUNT", cast=str, default="/static")
-STATIC_NAME = config("STATIC_NAME", cast=str, default="static")
-FAVICON = config(
-    "FAVICON", cast=str, default=""
-)  # If False gets value from https://elimintz.github.io/favicon.png
-TAILWIND = config("TAILWIND", cast=bool, default=True)
-QUASAR = config("QUASAR", cast=bool, default=False)
-QUASAR_VERSION = config("QUASAR_VERSION", cast=str, default=None)
-HIGHCHARTS = config("HIGHCHARTS", cast=bool, default=True)
-KATEX = config("KATEX", cast=bool, default=False)
-VEGA = config("VEGA", cast=bool, default=False)
-BOKEH = config("BOKEH", cast=bool, default=False)
-PLOTLY = config("PLOTLY", cast=bool, default=False)
-DECKGL = config("DECKGL", cast=bool, default=False)
-AGGRID = config("AGGRID", cast=bool, default=True)
-AGGRID_ENTERPRISE = config("AGGRID_ENTERPRISE", cast=bool, default=False)
-
-NO_INTERNET = config("NO_INTERNET", cast=bool, default=True)
-HTML_404_PAGE = "justpy is sorry - that path doesn't exist"
-
-
 def create_component_file_list():
     file_list = []
     component_dir = os.path.join(STATIC_DIRECTORY, "components")
@@ -123,7 +78,7 @@ logging.basicConfig(level=LOGGING_LEVEL, format="%(levelname)s %(module)s: %(mes
 middleware = [Middleware(GZipMiddleware)]
 if SSL_KEYFILE and SSL_CERTFILE:
     middleware.append(Middleware(HTTPSRedirectMiddleware))
-app = Starlette(middleware=middleware, debug=DEBUG)
+app = JustpyApp(middleware=middleware, debug=DEBUG)
 app.mount(STATIC_ROUTE, StaticFiles(directory=STATIC_DIRECTORY), name=STATIC_NAME)
 app.mount(
     "/templates", StaticFiles(directory=current_dir + "/templates"), name="templates"
@@ -156,10 +111,6 @@ def server_error_func(request):
     )
     return wp
 
-
-cookie_signer = Signer(str(SECRET_KEY))
-
-
 @app.on_event("startup")
 async def justpy_startup():
     WebPage.loop = asyncio.get_event_loop()
@@ -176,50 +127,24 @@ async def justpy_startup():
 
 
 @app.route("/{path:path}")
-class Homepage(HTTPEndpoint):
+class Homepage(JustpyEndpoint):
     """
     Justpy main page handler
     """
-
-    async def get(self, request):
-        # Handle web requests
-        session_cookie = request.cookies.get(SESSION_COOKIE_NAME)
-        if SESSIONS:
-            new_cookie = False
-            if session_cookie:
-                try:
-                    session_id = cookie_signer.unsign(session_cookie).decode("utf-8")
-                except:
-                    return PlainTextResponse("Bad Session")
-                request.state.session_id = session_id
-                request.session_id = session_id
-            else:
-                # Create new session_id
-                request.state.session_id = str(uuid.uuid4().hex)
-                request.session_id = request.state.session_id
-                new_cookie = True
-                logging.debug(f"New session_id created: {request.session_id}")
-        func = JpRoute.get_func_for_request(request)
-        if not func:
-            return HTMLResponse(content=HTML_404_PAGE, status_code=404)
-        func_to_run = func
-        func_parameters = len(inspect.signature(func_to_run).parameters)
-        assert (
-            func_parameters < 2
-        ), f"Function {func_to_run.__name__} cannot have more than one parameter"
-        if inspect.iscoroutinefunction(func_to_run):
-            if func_parameters == 1:
-                load_page = await func_to_run(request)
-            else:
-                load_page = await func_to_run()
-        else:
-            if func_parameters == 1:
-                load_page = func_to_run(request)
-            else:
-                load_page = func_to_run()
-        if isinstance(load_page, Response):
-            logging.debug("Returning raw starlette.responses.Response.")
-            return load_page
+    
+    
+    def get_response_for_load_page(self,request,load_page):
+        """
+        get the response for the given webpage
+        
+        Args:
+            request(Request): the request to handle
+            load_page(WebPage): the webpage to wrap with justpy and  
+            return as a full HtmlResponse
+        
+        Returns:
+            Reponse: the response for the given load_page
+        """
         page_type = type(load_page)
         assert issubclass(
             page_type, WebPage
@@ -261,18 +186,10 @@ class Homepage(HTTPEndpoint):
         context_obj = Context(context)
         context["context_obj"] = context_obj
         response = templates.TemplateResponse(load_page.template_file, context)
-        if SESSIONS and new_cookie:
-            cookie_value = cookie_signer.sign(request.state.session_id)
-            cookie_value = cookie_value.decode("utf-8")
-            response.set_cookie(
-                SESSION_COOKIE_NAME, cookie_value, max_age=COOKIE_MAX_AGE, httponly=True
-            )
-            for k, v in load_page.cookies.items():
-                response.set_cookie(k, v, max_age=COOKIE_MAX_AGE, httponly=True)
-        if LATENCY:
-            await asyncio.sleep(LATENCY / 1000)
         return response
-
+    
+    
+        
     async def post(self, request):
         # Handles post method. Used in Ajax mode for events when websockets disabled
         if request["path"] == "/zzz_justpy_ajax":
@@ -389,11 +306,11 @@ class JustpyEvents(WebSocketEndpoint):
             )
             print("WebPages: ", len(WebPage.instances), WebPage.instances)
             print("Sockets: ", len(WebPage.sockets), WebPage.sockets)
+            import psutil
             process = psutil.Process(os.getpid())
             print(f"Memory used: {process.memory_info().rss:,}")
             print("************************")
 
-
 async def handle_event(data_dict, com_type=0, page_event=False):
     # com_type 0: websocket, con_type 1: ajax
     connection_type = {0: "websocket", 1: "ajax"}
