@@ -11,8 +11,21 @@ import justpy as jp
 from starlette.testclient import TestClient
 from justpy.routing import JpRoute
 from tests.basetest import Basetest
+from starlette.responses import PlainTextResponse
+from jpcore.justpy_config import HTML_404_PAGE
 
+@jp.app.route("/plaintext")
+async def plainText(_request):
+    return PlainTextResponse("Plaintext")
 
+@jp.app.route("/urlFor/{name}")
+async def urlFor(request):
+    name=request.path_params["name"]
+    print(f"calling url_for {name}")
+    url=request.url_for(name)
+    return PlainTextResponse(url)
+
+@jp.app.route("/greet/{name}")
 @jp.SetRoute("/greet/{name}")
 def greeting_function(request):
     wp = jp.WebPage()
@@ -20,14 +33,14 @@ def greeting_function(request):
     wp.add(jp.P(text=f"Hello there, {name}!", classes="text-5xl m-2"))
     return wp
 
-
+#@jp.app.route("/bye")
 @jp.SetRoute("/bye", name="bye")
 def bye_function(_request):
     wp = jp.WebPage()
     wp.add(jp.P(text="Bye bye!", classes="text-5xl m-2"))
     return wp
 
-
+#@jp.app.route("/hello")
 @jp.SetRoute("/hello", name="hello")
 def hello_function(_request):
     wp = jp.WebPage()
@@ -35,7 +48,6 @@ def hello_function(_request):
     # print("request  = ", request.url_for("hello"))
     return wp
 
-
 class TestRouteAndUrlFor(Basetest):
     """
     test the url_for functionality
@@ -44,16 +56,25 @@ class TestRouteAndUrlFor(Basetest):
     def setUp(self, debug=False, profile=True):
         Basetest.setUp(self, debug=debug, profile=profile)
         self.app = jp.app
+        self.app.prioritize_routes()
+        
+    def testStarletteRoutes(self):
+        debug=True
+        for i,route in enumerate(self.app.router.routes):
+            route_as_text = self.app.route_as_text(route)
+            if debug:
+                print(f"{i}:{route_as_text}")
+            
 
-    def testRoute(self):
+    def testJpRoute(self):
         """
         Test the routing
         """
         self.assertEqual(3, len(JpRoute.routes_by_path))
         debug = self.debug
-        # debug=True
+        debug=True
         for route in JpRoute.routes_by_path.values():
-            route_as_text = str(route)
+            route_as_text = self.app.route_as_text(route)
             if debug:
                 print(route_as_text)
         for path in ["/bye", "/hello", "/greet/{name}"]:
@@ -70,6 +91,8 @@ class TestRouteAndUrlFor(Basetest):
         """
         if debug is None:
             debug = self.debug
+        if debug:
+            print(f"checking response for {path}")
         with TestClient(self.app) as client:
             response = client.get(path)
             self.assertEqual(expected_code, response.status_code)
@@ -81,15 +104,31 @@ class TestRouteAndUrlFor(Basetest):
         """
         Test url for functionality
         """
-        # @TODO - not implemented yet
-        pass
+        for name,url in [
+            ("plainText","plaintext"),
+            #("hello_function","hello")
+            ]:
+            path=f"/urlFor/{name}"
+            response=self.checkResponse(path)
+            urlfor=response.text
+            print(urlfor)
+            self.assertEqual(urlfor,f"http://testserver/{url}")
+            pass
+    
+    def testResponses(self):
+        
+        for path in [
+            "/plaintext",
+            #"/hello","/greet/eli","/bye"
+            ]:
+            _response=self.checkResponse(path,debug=True)
 
     def testInvalidPath(self):
         """
         test handling an invalid path
         """
         response = self.checkResponse("/invalidpath", 404)
-        self.assertEqual(jp.HTML_404_PAGE, response.text)
+        self.assertEqual(HTML_404_PAGE, response.text)
 
     def testStaticPath(self):
         """
@@ -109,4 +148,4 @@ class TestRouteAndUrlFor(Basetest):
             print(response.text)
             print(f"{len(lines)} lines")
         self.assertTrue(response.text.startswith("<!DOCTYPE html>"))
-        self.assertTrue(len(lines) < 500)
+        self.assertTrue(len(lines) < 80)
